/*
*---------------------------------------------------------------------------------------*
*  Header file Spinel                                                                     *
*                                                                                       *
* (c) PaPouch s.r.o. www.papouch.com	 								*
* Zari 2003                                                         		        	*
*---------------------------------------------------------------------------------------*
*/

#ifndef SPINEL_HEADER_FILE
#define SPINEL_HEADER_FILE 1

// definice odpovedi (ACK)
#define	ACK_OK		0x00		// OK
#define	ACK_BAD_I	0x02		// neplatna instrukce
#define	ACK_BAD_D	0x03		// neplatna data
#define	ACK_WD_AD	0x04		// zakazany zapis / pristup odmitnut
#define	ACK_DEV_ERR	0x05		// HW chyba zarizeni
#define	ACK_AUTO	0x0E		// automaticky generovany vystup 

#define MAXBLEN		0x64		// maximalni delka bufferu
#define	RXBUFS		0xff

// -------- Prikazy Spinelu

#define	C_WCOM		0xe0		// zapis komunikacnich parametru
#define	C_RCOM		0xf0		// cteni komunikacnich parametru
#define	C_WSTAT		0xe1		// zapis status byte
#define	C_RSTAT		0xf1		// cteni status byte
#define	C_WUD		0xe2		// zapis uzivatelskych dat
#define	C_RESET		0xe3		// reset zarizeni
#define	C_CEN		0xe4		// povoleni konfigurace
#define	C_SCSC		0xee		// povoleni checksumu
#define	C_RCSC		0xfe		// cteni povoleni checksumu
#define	C_RUD		0xf2		// cteni uzivatelskych dat
#define	C_NAME		0xf3		// dotaz na jmeno a typ zarizeni
#define	C_RCE		0xf4		// cteni chyb komunikace

#define	RS485		1			// podmineny preklad casti pro simplexni komunikaci

#define	DEF_SPINADDR	0x01;
#define	DEF_SPINSPD		0x06;


#define S_U0TENL   IRQ0E1 |= 0x08         	// L povoleni preruseni od vysilani
#define C_U0TENL   IRQ0E1 &= 0xF7			// L zakaz preruseni od vysilani
#define S_U0TXI		IRQ0 |= 0x08			// nastaveni priznaku interruptu
#define C_U0TXI		IRQ0 |= 0xf7			// nulovani priznaku interruptu
#define C_DE      	PAOUT &= ~0x04   // shodit DE0 (PA2) 
#define S_DE       	PAOUT |= 0x04   // nahodit DE0 (PA2)


extern unsigned char spin_r_flags;	// priznaky prijmu
#define		NOREC 		FALSE		// priznak pokud se neprijima
#define		RECEIVED	TRUE		// priznak pokud je prijem hotov			

extern unsigned char spin_t_flags;			// nulovat vsechny priznaky
#define		NOTX 		FALSE				// priznak pokud se nevysila
#define		TRANSMIT	NOTX + 1			// priznak vysilani


extern unsigned char 	spin_flags;	// priznaky spinelu
#define		RX_BC		0x01		// priznak broadcastu


extern unsigned char 		broadcast;	 	// prijem zpravy s broadcast adresou
extern unsigned char 		spin_addr;	 	// nastavena adresa
extern unsigned char 		format; 		// format
extern unsigned char 		ack;	 		// odpoved
extern unsigned char 		sig;	 		// podpis
extern unsigned char far 	recstr[];  		// prijaty retezec
extern unsigned char far 	message[]; 		// vysilana zprava
extern unsigned char 		txformat;	 	// format vysilanych dat
extern unsigned int  		txlen;	 		// delka vysilani
extern unsigned char 		check_cs;		// priznak kontroly checksumu
extern unsigned char 		rswaitc;		// citac prodlevy mezi RxTx
#define      RSWAIT      	5 				// prodleva Rx-Tx * 500us
extern unsigned char far 	hexstr[];		// hex cislo v HESCII formatu
extern unsigned char 		commerr;		// citac chyb komunikace
extern unsigned char 		commspeed;		// index komunikacni rychlosti
extern unsigned char volatile far *p_rx_h_buff;			// ukazatel na HW buffer

extern unsigned int const UARTspd[];		// tabulka rychlosti


extern void isr_u0rx(void);
extern void isr_u0tx(void);
extern void isr_DMA(void);
extern void init_DMA0(void);
extern unsigned char u0rx(void);

/*------------------------------------------------------------------
 Serial Init

 inicializace seriove komunikace
-------------------------------------------------------------------*/
extern void init_serial(void);

extern void send_name(void);		// vypis jmena
/*============================================================================
  Create & Send Message 
  
  vytvori kompletni zpravu podle zadaneho formatu a zahaji vysilani
  
  vstup:	format
  			sig
			ack
  			delka zpravy (pocet byte)
        	retezec

  POZOR: Delka zpravy vcetne hlavicky a paticky muze byt max. 256 byte
============================================================================*/
extern void cs_sp_message(unsigned char, unsigned char, unsigned char, unsigned char, unsigned char *); 

#endif

/* prijata instrukce je ulozena v recstr takto:
0. - format
1. - adresa
2. - podpis
3. - delka samotne instrukce/dat bez checksumu a CR
4. - zde zacina samotna instrukce
*/ 
